@@ -18,7 +18,7 @@
 #
 #   --  Gregory P. Smith <greg@krypto.org>
 #
-# $Id: test_dbtables.py,v d87999ccda75 2011/03/08 13:51:01 jcea $
+# $Id: test_dbtables.py,v 53e5f052c511 2012/01/16 18:18:15 jcea $
 
 import os, re, sys
 
@@ -38,11 +38,6 @@ from test_all import db, dbtables, test_support, verbose, \
 #----------------------------------------------------------------------
 
 class TableDBTestCase(unittest.TestCase):
-    import sys
-    if sys.version_info < (2, 4) :
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-
     db_name = 'test-table.db'
 
     def setUp(self):
