@@ -137,6 +137,10 @@ import traceback
 
 from distutils.util import get_platform
 
+# We need to be able to test BDB releases, even if the license is incompatible
+os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
+
+
 PROGRAM = sys.argv[0]
 PLAT_SPEC = "%s-%s" % (get_platform(), sys.version[0:3])
 # This hack copied from distutils.command.build.  Too bad distutils
@@ -334,7 +338,8 @@ class TestFileFinder:
 
     def module_from_path(self, path):
         """Return the Python package name indiciated by the filesystem path."""
-        assert path.endswith('.py')
+        if not path.endswith('.py') :
+            raise AssertionError()
         path = path[self._plen:-3]
         mod = path.replace(os.sep, '.')
         return mod
@@ -588,7 +593,7 @@ def print_tb_last():
     file = sys.stderr
     while True:
         f = tb.tb_frame
-        lineno = traceback.tb_lineno(tb)
+        lineno = tb.tb_lineno
         tb = tb.tb_next
         if tb is not None:
             continue
