@@ -19,8 +19,7 @@ Options:
 -b
     Run "python setup.py build" before running tests, where "python" is the
     version of python used to run test.py.  Highly recommended.  Tests will be
-    run from the build directory.  (Note: In Python < 2.3 the -q flag is
-    added to the setup.py command line.)
+    run from the build directory.
 
 -B
     Run "python setup.py build_ext -i" before running tests.  Tests will be
@@ -138,6 +137,10 @@ import traceback
 
 from distutils.util import get_platform
 
+# We need to be able to test BDB releases, even if the license is incompatible
+os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
+
+
 PROGRAM = sys.argv[0]
 PLAT_SPEC = "%s-%s" % (get_platform(), sys.version[0:3])
 # This hack copied from distutils.command.build.  Too bad distutils
@@ -335,7 +338,8 @@ class TestFileFinder:
 
     def module_from_path(self, path):
         """Return the Python package name indiciated by the filesystem path."""
-        assert path.endswith('.py')
+        if not path.endswith('.py') :
+            raise AssertionError()
         path = path[self._plen:-3]
         mod = path.replace(os.sep, '.')
         return mod
@@ -429,6 +433,7 @@ def runner(files, test_filter, debug):
             pdb.post_mortem(sys.exc_info()[2])
         else:
             raise
+    return r
 
 
 def main(module_filter, test_filter):
@@ -450,7 +455,7 @@ def main(module_filter, test_filter):
         gui_runner(files, test_filter)
     elif LOOP:
         while True:
-            runner(files, test_filter, debug)
+            r = runner(files, test_filter, debug)
     elif TRACE:
         coverdir = os.path.join(os.getcwd(), "coverage")
         import trace
@@ -461,7 +466,9 @@ def main(module_filter, test_filter):
         r = tracer.results()
         r.write_results(show_missing=True, summary=True, coverdir=coverdir)
     else:
-        runner(files, test_filter, debug)
+        r = runner(files, test_filter, debug)
+    bad = r.errors + r.failures
+    return bad
 
 
 def process_args(argv=None):
@@ -559,11 +566,7 @@ def process_args(argv=None):
 
     # Do the builds
     if build:
-        # Python 2.3 is more sane in its non -q output
-        qflag = '-q'
-        if sys.hexversion >= 0x02030000:
-            qflag = ''
-        cmd = sys.executable + ' setup.py ' + qflag + ' build'
+        cmd = sys.executable + ' setup.py build'
         if build_inplace:
             cmd += '_ext -i'
         sts = os.system(cmd)
@@ -590,7 +593,7 @@ def print_tb_last():
     file = sys.stderr
     while True:
         f = tb.tb_frame
-        lineno = traceback.tb_lineno(tb)
+        lineno = tb.tb_lineno
         tb = tb.tb_next
         if tb is not None:
             continue
